(ns wanijo.main
  (:require [ring.adapter.jetty :refer [run-jetty]]
            [wanijo.handler :as wanijo-handler]
            [nrepl.server :as nrepl])
  (:gen-class))

(defonce server (atom nil))

(defn start-server!
  [& {:keys [port join?]
      :or {port 3080
           join? true}}]
  (reset! server
          (run-jetty wanijo-handler/standalone-app
                     {:port port
                      :join? join?})))

(defn start-server-dev! []
  (start-server! :join? false
                 :port 8080
                 :handler wanijo-handler/dev-app))

(defn stop-server! []
  (when @server
    (.stop @server)))

(defn restart-server-dev! []
  (stop-server!)
  (start-server-dev!))

(defn -main [& args]
  (let [nrepl-port (Integer/valueOf (or (System/getenv "NREPL_PORT")
                                        "7888"))
        web-port (Integer/valueOf (or (System/getenv "WEB_PORT")
                                      "3080"))]
    (println "starting nrepl on port " nrepl-port)
    (nrepl/start-server :port nrepl-port)

    (println "starting web server on port " web-port)
    (start-server! :port web-port
                   :join? false)))
